# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lancedb.github.io/lance-namespace/spec/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lancedb.github.io/lance-namespace/spec/impls/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CreateEmptyTableResponse(BaseModel):
    """
    Response for creating an empty table. 
    """ # noqa: E501
    location: Optional[StrictStr] = None
    properties: Optional[Dict[str, StrictStr]] = None
    storage_options: Optional[Dict[str, StrictStr]] = Field(default=None, description="Configuration options to be used to access storage. The available options depend on the type of storage in use. These will be passed directly to Lance to initialize storage access. ")
    __properties: ClassVar[List[str]] = ["location", "properties", "storage_options"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateEmptyTableResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateEmptyTableResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "location": obj.get("location"),
            "properties": obj.get("properties"),
            "storage_options": obj.get("storage_options")
        })
        return _obj





# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lancedb.github.io/lance-namespace/spec/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lancedb.github.io/lance-namespace/spec/impls/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.models.create_table_tag_request import CreateTableTagRequest

class TestCreateTableTagRequest(unittest.TestCase):
    """CreateTableTagRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateTableTagRequest:
        """Test CreateTableTagRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateTableTagRequest`
        """
        model = CreateTableTagRequest()
        if include_optional:
            return CreateTableTagRequest(
                id = [
                    ''
                    ],
                tag = '',
                version = 0
            )
        else:
            return CreateTableTagRequest(
                tag = '',
                version = 0,
        )
        """

    def testCreateTableTagRequest(self):
        """Test CreateTableTagRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lancedb.github.io/lance-namespace/spec/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lancedb.github.io/lance-namespace/spec/impls/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.models.fts_query import FtsQuery

class TestFtsQuery(unittest.TestCase):
    """FtsQuery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FtsQuery:
        """Test FtsQuery
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FtsQuery`
        """
        model = FtsQuery()
        if include_optional:
            return FtsQuery(
                match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                    boost = 1.337, 
                    column = '', 
                    fuzziness = 0, 
                    max_expansions = 0, 
                    operator = 'And', 
                    prefix_length = 0, 
                    terms = '', ),
                phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                    column = '', 
                    slop = 0, 
                    terms = '', ),
                boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                    positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                        match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                            column = '', 
                            fuzziness = 0, 
                            max_expansions = 0, 
                            operator = 'And', 
                            prefix_length = 0, 
                            terms = '', ), 
                        phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                            column = '', 
                            slop = 0, 
                            terms = '', ), 
                        multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                            match_queries = [
                                lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                    column = '', 
                                    fuzziness = 0, 
                                    max_expansions = 0, 
                                    prefix_length = 0, 
                                    terms = '', )
                                ], ), 
                        boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                            must = [
                                lance_namespace_urllib3_client.models.fts_query.FtsQuery()
                                ], 
                            must_not = [
                                
                                ], 
                            should = [
                                
                                ], ), ), 
                    negative = , 
                    negative_boost = 1.337, ),
                multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                    match_queries = [
                        lance_namespace_urllib3_client.models.match_query.MatchQuery(
                            boost = 1.337, 
                            column = '', 
                            fuzziness = 0, 
                            max_expansions = 0, 
                            operator = 'And', 
                            prefix_length = 0, 
                            terms = '', )
                        ], ),
                boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                    must = [
                        lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                            match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                boost = 1.337, 
                                column = '', 
                                fuzziness = 0, 
                                max_expansions = 0, 
                                operator = 'And', 
                                prefix_length = 0, 
                                terms = '', ), 
                            phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                                column = '', 
                                slop = 0, 
                                terms = '', ), 
                            boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                                positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                                    multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                        match_queries = [
                                            lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                                column = '', 
                                                fuzziness = 0, 
                                                max_expansions = 0, 
                                                prefix_length = 0, 
                                                terms = '', )
                                            ], ), ), 
                                negative = , 
                                negative_boost = 1.337, ), 
                            multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                match_queries = [
                                    
                                    ], ), )
                        ], 
                    must_not = [
                        
                        ], 
                    should = [
                        
                        ], )
            )
        else:
            return FtsQuery(
        )
        """

    def testFtsQuery(self):
        """Test FtsQuery"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
